/*
 * Copyright (C) 2011, Jamie Thompson
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; If not, see
 * <http://www.gnu.org/licenses/>.
 */

#include "Fmms.h"

using namespace DBBackends;

Fmms::Fmms(const Settings &settings) :
	m_Settings(settings)
{
}

Fmms::Fmms(const Settings &settings, const EventTypes::FmmsEvent &/*event*/) :
	m_Settings(settings)
{
}

void Fmms::Process(EventProcessors::iEventProcessor &/*eventProcessor*/)
{

}

EventTypes::iEvent *const Fmms::CreateEvent(int &/*fevent*/, QList<void *> &/*fattachments*/)
{
	return 0;
}

void Fmms::PreInsert()
{
}

void Fmms::Insert(EventTypes::iEvent &/*event*/, const NumberToNameLookup &/*numberToNameLookup*/)
{
	return;
}

void Fmms::PostInsert()
{
}

void Fmms::ClearInsertedIDs()
{
	InsertedIDs().clear();
}

